@@ -43,6 +43,8 @@ define ldflags_uselargefiles ''
 define libs_uselargefiles ''
 define libswanted_uselargefiles ''
 
+define default_inc_excludes_dot 'define'
+
 # These are sometimes used in perl-cross, and sometimes also affect modules
 # Some *must* be "false" instead of "undef"! See configure_args.sh
 define use64bitall 'undef'
@@ -75,6 +77,7 @@ define usesfio 'false'
 define useshrplib 'false'
 define usesitecustomize 'undef'
 define usesocks 'undef'
+define usedefaultstrict 'undef'
 define useversionedarchname 'undef'
 define usevfork 'false'
 
@@ -177,6 +180,7 @@ define d_voidtty 'define'
 define d_semctl_semid_ds 'define'
 define d_semctl_semun 'define'
 define d_setlocale_accepts_any_locale_name 'undef'
+define d_getenv_preserves_other_thread 'undef'
 
 define d_msg_ctrunc 'undef'
 define d_msg_dontroute 'undef'
